
Requirements Summary
====================

# default

## As a user, I want to generate AIPs and SIPs using Registry ([#7](https://github.com/NASA-PDS/pds-deep-archive/issues/7)) 


This requirement is not impacted by the current version
## As a user, I want the SIP manifest to include valid URLs ([#102](https://github.com/NASA-PDS/pds-deep-archive/issues/102)) 


This requirement is not impacted by the current version
# NSSDCA-delivery-requirements

## The tool shall be capable of generating a valid Archive Information Package transfer manifest and PDS4 XML label in accordance with the PDS4 Information Model ([#45](https://github.com/NASA-PDS/pds-deep-archive/issues/45)) 


This requirement is not impacted by the current version
## The tool shall be capable of generating a valid AIP and SIP products and PDS4 XML label in accordance with the PDS4 Information Model ([#46](https://github.com/NASA-PDS/pds-deep-archive/issues/46)) 


This requirement is not impacted by the current version
## The tool shall be capable of generating product manifests from an online Registry Service ([#47](https://github.com/NASA-PDS/pds-deep-archive/issues/47)) 


This requirement is not impacted by the current version
## The tool shall be capable of generating product manifests by crawling a file system using the information contained within the specified bundle and collection products ([#48](https://github.com/NASA-PDS/pds-deep-archive/issues/48)) 


This requirement is not impacted by the current version
## The tool shall generate a product manifest based upon the specification of a bundle as input ([#49](https://github.com/NASA-PDS/pds-deep-archive/issues/49)) 


This requirement is not impacted by the current version
## The tool shall include products in the manifests based upon the relationships described in the PDS4 bundle and collection metadata ([#50](https://github.com/NASA-PDS/pds-deep-archive/issues/50)) 


This requirement is not impacted by the current version
## The tool shall be capable of accepting a checksum manifest as input to use in place of Registry or on-demand product checksum generation ([#51](https://github.com/NASA-PDS/pds-deep-archive/issues/51)) 


This requirement is not impacted by the current version
## The tool shall generate a PDS4 label for the SIP and AIP using at least PDS4 Information Model v1.13.0.0 ([#52](https://github.com/NASA-PDS/pds-deep-archive/issues/52)) 


This requirement is not impacted by the current version
## The tool shall require AIP and SIP products contain only products with valid logical identifiers according to the PDS4 Standards Reference ([#53](https://github.com/NASA-PDS/pds-deep-archive/issues/53)) 


This requirement is not impacted by the current version
## The Submission Information Package manifest shall be a tab-delimited table with one record per product and four fields per record containing the following fields: checksum value, checksum type, resolvable URL to data product, unique product lidvid for the associated product ([#54](https://github.com/NASA-PDS/pds-deep-archive/issues/54)) 


This requirement is not impacted by the current version